# コントリビューター行動規範

## 私たちの誓い

私たちメンバー、コントリビューター、リーダーは、年齢、体型、可視的または不可視的な障害、民族性、性的特徴、性自認および表現、経験レベル、教育、社会経済的地位、国籍、外見、人種、宗教、性的自認および指向に関わらず、誰もがハラスメントのない体験ができるコミュニティへの参加を誓います。

私たちは、オープンで歓迎的で多様性に富み、包括的で健全なコミュニティに貢献する方法で行動し、交流することを誓います。

## 私たちの基準

私たちのコミュニティにポジティブな環境をもたらす行動の例には、以下が含まれます：

* 他の人々に対して共感と思いやりを示すこと
* 異なる意見、視点、経験を尊重すること
* 建設的なフィードバックを与え、優雅に受け入れること
* 責任を受け入れ、私たちの過ちによって影響を受けた人々に謝罪し、その経験から学ぶこと
* 個人としてだけでなく、コミュニティ全体にとって最善なことに焦点を当てること

許容できない行動の例には以下が含まれます：

* 性的な表現やイメージの使用、およびあらゆる種類の性的な関心やアプローチ
* 荒らし、侮辱的または軽蔑的なコメント、個人的または政治的な攻撃
* 公的または私的な嫌がらせ
* 物理的住所やメールアドレスなど、他人のプライベート情報を明示的な許可なしに公開すること
* 専門的な環境において不適切と合理的に考えられるその他の行為

## 施行責任

コミュニティリーダーは、許容可能な行動基準を明確にし、施行する責任があり、不適切、脅威的、攻撃的、または有害と判断される行動に対して適切かつ公正な是正措置を取ります。

コミュニティリーダーは、この行動規範に沿わないコメント、コミット、コード、Wiki編集、イシュー、その他の貢献を削除、編集、または拒否する権利と責任を有し、適切な場合にはモデレーション決定の理由を説明します。

## 範囲

この行動規範は、すべてのコミュニティスペース内で適用され、また個人が公式にコミュニティを代表して公共の場で行動する場合にも適用されます。  
私たちのコミュニティを代表する例としては、公式メールアドレスの使用、公式ソーシャルメディアアカウントからの投稿、オンラインまたはオフラインイベントでの任命された代表者としての行動などが含まれます。

## 強制執行

虐待的、嫌がらせ的、またはその他の容認できない行為の事例は、施行を担当するコミュニティリーダーに aw@funstory.ai まで報告することができます。  
すべての苦情は迅速かつ公平に審査および調査されます。  

すべてのコミュニティリーダーは、いかなる事件の報告者のプライバシーとセキュリティを尊重する義務があります。

## 施行ガイドライン

コミュニティリーダーは、この行動規範に違反すると判断した行動に対して、以下のコミュニティ影響ガイドラインに従って結果を決定します：

### 1. 修正

**コミュニティへの影響**：不適切な言語の使用や、コミュニティにおいてプロフェッショナルでない、または歓迎されないとみなされるその他の行動。

**結果**：コミュニティリーダーからの非公開の書面による警告。違反の性質と、その行動がなぜ不適切であったのかについての説明が提供されます。公開謝罪が求められる場合があります。

### 2. 警告

**コミュニティへの影響**：単一の出来事または一連の行動による違反。

**結果**：継続的な行動に対する結果を伴う警告。指定された期間、関係者とのやり取りを禁止します。これには、行動規範を施行する人々との不請願なやり取りも含まれます。コミュニティスペースだけでなく、ソーシャルメディアなどの外部チャンネルでのやり取りも避ける必要があります。これらの条件に違反すると、一時的または永久的な利用停止になる可能性があります。

### 3. 一時的な利用停止

**コミュニティへの影響**：持続的な不適切な行動を含む、コミュニティ基準に対する重大な違反。

**結果**：指定された期間、コミュニティとのあらゆる種類の交流や公開コミュニケーションが一時的に禁止されます。この期間中、関係者との公開または非公開の交流、行動規範を施行する者との許可されていない交流は一切認められません。これらの条件に違反した場合、永久追放につながる可能性があります。

### 4. 永久追放

**コミュニティへの影響**：コミュニティ基準の違反パターンの実証。これには、持続的な不適切な行動、個人への嫌がらせ、または特定のグループに対する攻撃や軽蔑が含まれます。

**結果**：コミュニティ内でのあらゆる種類の公的な関与からの永久追放。

## クレジット

この行動規範は、[Contributor Covenant][homepage] バージョン 2.0 を基に作成されており、
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html で閲覧可能です。

コミュニティ影響ガイドラインは、[Mozilla の行動規範施行ラダー](https://github.com/mozilla/diversity) にインスパイアされています。

[homepage]: https://www.contributor-covenant.org

この行動規範に関するよくある質問への回答は、FAQ ページ https://www.contributor-covenant.org/faq を参照してください。翻訳版は https://www.contributor-covenant.org/translations で入手可能です。

<div align="right"> 
<h6><small>このページの一部のコンテンツはGPTによって翻訳されており、エラーが含まれている可能性があります。</small></h6>